@@ -87,7 +87,7 @@ void BomberBoard::resetPlane()
 
 void BomberBoard::resize(QSize & size)
 {
-    setBackgroundBrush(m_renderer->spritePixmap(QLatin1Literal("background"), size));
+    setBackgroundBrush(m_renderer->spritePixmap(QStringLiteral("background"), size));
 
     unsigned int minTileSizeWidth = size.width() / TILE_NUM_W;
     unsigned int minTileSizeHeight = size.height() / TILE_NUM_H;
@@ -236,7 +236,7 @@ void BomberBoard::bombHit(Bomb * bomb, qreal moveBombToX, qreal moveBombToY)
     bomb->setPosition(moveBombToX, moveBombToY);
     bomb->setState(Bomb::State::Exploding);
     m_explodingBombs.enqueue(bomb);
-    QTimer::singleShot(BOMB_EXPLODE_TIME, this, SLOT(bombExploded()));
+    QTimer::singleShot(BOMB_EXPLODE_TIME, this, &BomberBoard::bombExploded);
     emit playBombSound();
 }
 
@@ -249,7 +249,7 @@ void BomberBoard::bombExploded()
 
 void BomberBoard::settingsChanged()
 {
-    setBackgroundBrush(m_renderer->spritePixmap(QLatin1Literal("background"), m_view->size()));
+    setBackgroundBrush(m_renderer->spritePixmap(QStringLiteral("background"), m_view->size()));
     redraw();
 }
 
@@ -264,7 +264,7 @@ void BomberBoard::crashed()
     QPointF pos = m_plane->position();
     m_plane->setPosition(pos.x() + 1, pos.y());
     m_plane->setState(Plane::State::Exploding);
-    QTimer::singleShot(PLANE_EXPLODE_TIME, this, SLOT(planeExploded()));
+    QTimer::singleShot(PLANE_EXPLODE_TIME, this, &BomberBoard::planeExploded);
     emit playCrashSound();
 }
 
